QueryDevice class abstract

@Description: base implementation for any device check

Implementers

Constructors

QueryDevice({required double minWidth, required double maxWidth, BuildContext? context, int? currentMaxWidth, Orientation? orientation})

Properties

context → BuildContext?
The build context of the current device
final
currentMaxWidth → int?
The max width size of the current device
final
hashCode → int
The hash code for this object.
no setterinherited
maxWidth → double
The max width of the query device
final
minWidth → double
The min width of the query device
final
orientation → Orientation?
An optional instance of the orientation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isLandscape() → bool
@Description check if the current context is with landscape view @Return: bool => bool check for this condition
isPortrait() → bool
@Description check if the current context is with portrait view @Return: bool => bool check for this condition
isPortraitLandscape() → bool
@Description check if the current context is with portrait and landscape view @Return: bool => bool check for this condition
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited