Fire8 class

@Description: it handles the following devices

  • Kindle Fire HD 8.9"
Inheritance

Constructors

Fire8(BuildContext? context, Orientation? orientation, int? currentMaxWidth)

Properties

context → BuildContext?
The build context of the current device
finalinherited
currentMaxWidth → int?
The max width size of the current device
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
maxWidth → double
The max width of the query device
finalinherited
minWidth → double
The min width of the query device
finalinherited
orientation → Orientation?
An optional instance of the orientation
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isLandscape() → bool
@Description check if the current context is with landscape view @Return: bool => bool check for this condition
inherited
isPortrait() → bool
@Description check if the current context is with portrait view @Return: bool => bool check for this condition
inherited
isPortraitLandscape() → bool
@Description check if the current context is with portrait and landscape view @Return: bool => bool check for this condition
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited